/*
    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>

    SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "systemAnalyzer.h"

SystemAnalyzer::SystemAnalyzer(LogMode *logMode)
    : SyslogAnalyzer(logMode)
{
}

#include "moc_systemAnalyzer.cpp"
